marktools.attach_lilypond_command_marks_to_components_in_expr
=============================================================

.. autofunction:: abjad.tools.marktools.attach_lilypond_command_marks_to_components_in_expr.attach_lilypond_command_marks_to_components_in_expr
